translate.convert.po2oo

Package translate :: Package convert :: Module po2oo |
[hide private]
[frames] | no frames]

# Module po2oo

source code

convert Gettext PO localization files to an OpenOffice.org (SDF) localization file

see: http://translate.sourceforge.net/wiki/toolkit/po2oo for examples and usage instructions

Classes | [hide private]
| reoo
| oocheckfilter
| oofilteroptions

Functions | [hide private]
getmtime(filename) | source code
convertoo(inputfile, outputfile, templatefile, sourcelanguage=None, targetlanguage=None, timestamp=None, includefuzzy=False, multifilestyle=`'``single``'`, skip_source=False, filteraction=None) | source code
main(argv=None) | source code

Variables | [hide private]
| options = `oofilteroptions()`
| filter = `oocheckfilter(options, [checks.OpenOfficeChecker, che`...``
| __package__ = ``'``translate.convert``'``

Imports: os, sys, time, oo, factory, pofilter, checks, autocorrect

Variables Details | [hide private]

  ### filter Value:
      oocheckfilter(options, [checks.OpenOfficeChecker, checks.StandardUnitC
      hecker], checks.openofficeconfig)